"use strict";(self.webpackChunk_streamlit_app=self.webpackChunk_streamlit_app||[]).push([[9330],{69330:function(e,t,r){r.r(t),r.d(t,{default:function(){return i}});var u=r(66845),n=r(40864);function i(e){var t=e.element,r=e.width,i=e.endpoints,s=(0,u.useRef)(null);(0,u.useEffect)((function(){s.current&&(s.current.currentTime=t.startTime)}),[t.startTime]);var a=i.buildMediaURL(t.url);return(0,n.jsx)("audio",{id:"audio",ref:s,controls:!0,src:a,className:"stAudio",style:{width:r}})}}}]);