"use strict";(self.webpackChunk_streamlit_app=self.webpackChunk_streamlit_app||[]).push([[1792],{61792:function(e,t,i){i.r(t),i.d(t,{default:function(){return d}});i(66845);var l=i(81354),r=i(27446),n=i(9003),s=i(21e3),a=i(40864);var d=function(e){var t=e.disabled,i=e.element,d=e.widgetMgr,u=e.width,c={width:u},h="primary"===i.type?l.nW.PRIMARY:l.nW.SECONDARY,o=!i.help||u;return(0,a.jsx)("div",{className:"row-widget stButton","data-testid":"stButton",style:c,children:(0,a.jsx)(r.t,{help:i.help,children:(0,a.jsx)(n.ZP,{kind:h,size:l.V5.SMALL,disabled:t,fluidWidth:!!i.useContainerWidth&&o,onClick:function(){return d.setTriggerValue(i,{fromUi:!0})},children:(0,a.jsx)(s.ZP,{source:i.label,allowHTML:!1,isLabel:!0,largerLabel:!0,disableLinks:!0})})})})}}}]);