"use strict";(self.webpackChunk_streamlit_app=self.webpackChunk_streamlit_app||[]).push([[3513],{33513:function(e,t,i){i.r(t),i.d(t,{default:function(){return d}});i(66845);var l=i(81354),a=i(27446),n=i(9003),r=i(21e3),s=i(40864);var d=function(e){var t=e.disabled,i=e.element,d=e.widgetMgr,u=e.width,o=e.endpoints,c={width:u},h="primary"===i.type?l.nW.PRIMARY:l.nW.SECONDARY,p=!i.help||u;return(0,s.jsx)("div",{className:"row-widget stDownloadButton","data-testid":"stDownloadButton",style:c,children:(0,s.jsx)(a.t,{help:i.help,children:(0,s.jsx)(n.ZP,{kind:h,size:l.V5.SMALL,disabled:t,onClick:function(){d.setTriggerValue(i,{fromUi:!0});var e=document.createElement("a"),t=o.buildMediaURL(i.url);e.setAttribute("href",t),e.setAttribute("target","_blank"),e.click()},fluidWidth:!!i.useContainerWidth&&p,children:(0,s.jsx)(r.ZP,{source:i.label,allowHTML:!1,isLabel:!0,largerLabel:!0,disableLinks:!0})})})})}}}]);