"use strict";(self.webpackChunk_streamlit_app=self.webpackChunk_streamlit_app||[]).push([[4500],{54500:function(t,e,r){r.r(e),r.d(e,{default:function(){return l}});var i=r(90994),n=(r(66845),r(40864));function l(t){var e,r,l=t.element,a=t.width,o=l.hasWidth?l.width:a;l.scrolling?(e="auto",r={}):(e="no",r={overflow:"hidden"});var c=s(l.src),u=null!=c?void 0:s(l.srcdoc);return(0,n.jsx)("iframe",{allow:i.p,style:r,src:c,srcDoc:u,width:o,height:l.height,scrolling:e,sandbox:i.T,title:"st.iframe"})}function s(t){return null==t||""===t?void 0:t}}}]);