(self.webpackChunk_streamlit_app=self.webpackChunk_streamlit_app||[]).push([[3956],{51307:function(t,i,e){"use strict";e.r(i),e.d(i,{default:function(){return h}});e(66845);var n,r=e(37929),a=e(82673),o=e(87077),l=e(1515),d=(0,l.Z)("div",{target:"e115fcil2"})((function(t){return{display:"flex",flexDirection:"row",flexWrap:"wrap",rowGap:t.theme.spacing.lg}}),""),c=(0,l.Z)("div",{target:"e115fcil1"})((function(){return{display:"flex",flexDirection:"column",alignItems:"stretch",width:"auto",flexGrow:0}}),""),s=(0,l.Z)("div",{target:"e115fcil0"})((function(t){var i=t.theme;return{fontFamily:i.genericFonts.bodyFont,fontSize:i.fontSizes.sm,color:i.colors.fadedText60,textAlign:"center",marginTop:i.spacing.xs,wordWrap:"break-word",padding:"0.125rem"}}),""),u=e(40864);!function(t){t[t.OriginalWidth=-1]="OriginalWidth",t[t.ColumnWidth=-2]="ColumnWidth",t[t.AutoWidth=-3]="AutoWidth"}(n||(n={}));var h=(0,a.Z)((function(t){var i,e=t.width,a=t.isFullScreen,l=t.element,h=t.height,f=t.endpoints,p=l.width;if(p===n.OriginalWidth||p===n.AutoWidth)i=void 0;else if(p===n.ColumnWidth)i=e;else{if(!(p>0))throw Error("Invalid image width: ".concat(p));i=p}var m={};return h&&a?(m.maxHeight=h,m["object-fit"]="contain"):(m.width=i,p===n.AutoWidth&&(m.maxWidth="100%")),(0,u.jsx)(d,{style:{width:e},children:l.imgs.map((function(t,i){var e=t;return(0,u.jsxs)(c,{"data-testid":"stImage",children:[e.markup?(0,r.ZP)((0,o.kB)(e.markup)):(0,u.jsx)("img",{style:m,src:f.buildMediaURL(e.url),alt:i.toString()}),e.caption&&(0,u.jsx)(s,{"data-testid":"caption",style:m,children:" ".concat(e.caption," ")})]},i)}))})}))},48577:function(){}}]);