"use strict";(self.webpackChunk_streamlit_app=self.webpackChunk_streamlit_app||[]).push([[6853],{76853:function(e,n,t){t.r(n),t.d(n,{default:function(){return m}});var r=t(66845),s=t(25621),i=t(95118),o=t(21e3),a=t(66694),l=t(1515),c=t(63637),u=t(60484),p=(0,l.Z)(c.Q,{shouldForwardProp:u.Z,target:"e1se5lgy1"})((function(e){var n=e.theme,t=e.$usingCustomTheme;return{marginTop:n.spacing.none,marginBottom:n.spacing.none,marginRight:n.spacing.none,marginLeft:n.spacing.none,borderColor:n.colors.fadedText10,borderTopColor:t?n.colors.primary:n.colors.blue70,flexGrow:0,flexShrink:0}}),""),g=(0,l.Z)("div",{target:"e1se5lgy0"})((function(e){return{display:"flex",gap:e.theme.spacing.lg,alignItems:"center",width:"100%"}}),""),d=t(40864);var m=function(e){var n=e.width,t=e.element,l=(0,s.u)(),c=r.useContext(a.E).activeTheme,u=!(0,i.MJ)(c),m={width:n};return(0,d.jsx)("div",{className:"stSpinner","data-testid":"stSpinner",style:m,children:(0,d.jsxs)(g,{children:[(0,d.jsx)(p,{$size:l.iconSizes.twoXL,$usingCustomTheme:u}),(0,d.jsx)(o.ZP,{source:t.text,allowHTML:!1})]})})}}}]);