(self.webpackChunk_streamlit_app=self.webpackChunk_streamlit_app||[]).push([[7805],{32508:function(t,e,i){"use strict";i.r(e),i.d(e,{default:function(){return s}});var n=i(66845),h=i(18157),a=i(91487),r=i(23849),c=i(82673),o=(0,i(1515).Z)("div",{target:"e1uym6o70"})((function(t){return{"& *":{fontFamily:t.theme.genericFonts.bodyFont,fontSize:"9.6px"},"& svg":{maxWidth:"100%"}}}),""),u=i(40864);a.graphviz;var s=(0,c.Z)((function(t){var e=t.width,i=t.element,c=t.height,s="graphviz-chart-".concat(i.elementId),d=0,f=0,g=function(){var t=f,n=d;return c?(t=e,n=c):i.useContainerWidth&&(t=e),{chartWidth:t,chartHeight:n}},p=function(){try{var t=(0,a.graphviz)("#".concat(s)).zoom(!1).fit(!0).scale(1).renderDot(i.spec).on("end",(function(){var t=(0,h.Ys)("#".concat(s," > svg")).node();t&&(d=t.getBBox().height,f=t.getBBox().width)})),e=g(),n=e.chartHeight,c=e.chartWidth;n>0&&t.height(n),c>0&&t.width(c)}catch(o){(0,r.H)(o)}};(0,n.useEffect)((function(){p()}));var v=g(),l=v.chartWidth?v.chartWidth:e,m=v.chartHeight?v.chartHeight:c;return(0,u.jsx)(o,{className:"graphviz stGraphVizChart",id:s,style:{width:l,height:m}})}))},47318:function(){},57516:function(){},38728:function(){}}]);